@@ -1,7 +1,10 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from infos import __author__, __license__, __version__, __description__
+__author__ = "Cyprien Devillez"
+__license__ = "GPL"
+__version__ = "0.0.9"
+__description__ = "Simple CLI tool to create and delete easily MySQL databases." 
 
 import sys
 import ConfigParser
